package com.company.sample.app;

import com.company.sample.entity.Customer;
import com.google.common.base.Strings;
import io.jmix.core.Metadata;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

@Component
public class CustomerService {

    @Autowired
    private Metadata metadata;

    public List<Customer> loadAllCustomers() {
        List<Customer> customers = new ArrayList<>();
        customers.add(createCustomer("Bob", "Smith", "bob@mail.com"));
        customers.add(createCustomer("John", "Doe", "john@mail.com"));
        customers.add(createCustomer("Jane", "Doe", "jane@mail.com"));
        return customers;
    }

    public List<Customer> loadCustomers(String firstName, String lastName) {
        return loadAllCustomers().stream()
                .filter(customer -> {
                    return (Strings.isNullOrEmpty(firstName) || firstName.equals(customer.getFirstName())) &&
                            (Strings.isNullOrEmpty(lastName) || lastName.equals(customer.getLastName()));
                })
                .collect(Collectors.toList());
    }

    private Customer createCustomer(String firstName, String lastName, String email) {
        Customer customer = metadata.create(Customer.class);
        customer.setFirstName(firstName);
        customer.setLastName(lastName);
        customer.setEmail(email);
        return customer;
    }
}